@@ -18,8 +18,8 @@
    You should have received a copy of the GNU General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>.  */
 
-#ifndef DISPLACED_STEPPING_H
-#define DISPLACED_STEPPING_H
+#ifndef GDB_DISPLACED_STEPPING_H
+#define GDB_DISPLACED_STEPPING_H
 
 #include "gdbsupport/array-view.h"
 #include "gdbsupport/byte-vector.h"
@@ -249,4 +249,4 @@ displaced_step_finish_status
   default_displaced_step_finish (target_ops *target, thread_info *thread,
 				 const target_waitstatus &status);
 
-#endif /* DISPLACED_STEPPING_H */
+#endif /* GDB_DISPLACED_STEPPING_H */
