@@ -1,7 +1,7 @@
 /* GDB HIP testing mode.
 
-   Copyright (C) 2021-2023 Free Software Foundation, Inc.
-   Copyright (C) 2021-2023 Advanced Micro Devices, Inc. All rights reserved.
+   Copyright (C) 2021-2024 Free Software Foundation, Inc.
+   Copyright (C) 2021-2024 Advanced Micro Devices, Inc. All rights reserved.
 
    This file is part of GDB.
 
@@ -21,13 +21,13 @@
 #ifndef GDB_HIP_TEST_MODE_H
 #define GDB_HIP_TEST_MODE_H
 
-#include "gdbsupport/gdb_string_view.h"
+#include <string_view>
 
 struct objfile;
 
 const char *gdb_hip_test_mode_frob_names (struct objfile *objfile,
 					  const char *name);
-gdb::string_view gdb_hip_test_mode_frob_names (struct objfile *objfile,
-					       gdb::string_view name);
+std::string_view gdb_hip_test_mode_frob_names (struct objfile *objfile,
+					       std::string_view name);
 
 #endif
