@@ -15,8 +15,8 @@
    You should have received a copy of the GNU General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>.  */
 
-#ifndef VAROBJ_H
-#define VAROBJ_H 1
+#ifndef GDB_VAROBJ_H
+#define GDB_VAROBJ_H
 
 #include "symtab.h"
 #include "gdbtypes.h"
@@ -358,4 +358,4 @@ extern void varobj_restrict_range (const std::vector<varobj *> &children,
 
 extern bool varobj_default_is_path_expr_parent (const struct varobj *var);
 
-#endif /* VAROBJ_H */
+#endif /* GDB_VAROBJ_H */
